@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ob-duckdb" "2.2.0"
+(define-package "ob-duckdb" "20251220.1924"
   "Org Babel integration for DuckDB CLI."
   '((emacs "28.1")
     (org   "9.5"))
